# Split平台自动化脚本

这个自动化脚本用于在用户完成USDT支付后，自动在Split平台上为用户购买Telegram Premium会员。

## 功能特点

- 完全自动化，无需人工干预
- 与USDT转账监听系统无缝集成
- 自动处理Split平台登录和购买流程
- 包含错误处理和重试机制
- 详细的日志记录和状态跟踪

## 技术架构

- 使用Puppeteer进行网页自动化
- Node.js运行环境
- 集成TON钱包扩展
- 安全的凭证管理
- 异步任务处理

## 安装与配置

### 环境要求

- Node.js 16+
- Chrome浏览器
- TON钱包扩展

### 安装步骤

1. 克隆代码库
2. 安装依赖：`npm install`
3. 配置环境变量和凭证
4. 运行初始化脚本：`node initialize.js`

## 使用方法

### 基本用法

```javascript
const { SplitAutomation } = require('./src/split-automation');

// 初始化自动化实例
const splitBot = new SplitAutomation({
  walletPath: '/path/to/wallet/extension',
  credentials: {
    walletSeed: 'your-wallet-seed-phrase',
    password: 'your-wallet-password'
  }
});

// 为用户购买Premium会员
async function buyPremiumForUser(telegramId, months, paymentTxHash) {
  try {
    await splitBot.initialize();
    const result = await splitBot.buyPremium(telegramId, months);
    console.log(`成功为用户 ${telegramId} 购买了 ${months} 个月的Premium会员`);
    return result;
  } catch (error) {
    console.error(`购买失败: ${error.message}`);
    throw error;
  } finally {
    await splitBot.close();
  }
}
```

### 与USDT监听系统集成

```javascript
const { UsdtMonitor } = require('./path/to/usdt-monitor');
const { SplitAutomation } = require('./src/split-automation');

// 初始化USDT监听器和Split自动化实例
const monitor = new UsdtMonitor(/* 配置 */);
const splitBot = new SplitAutomation(/* 配置 */);

// 设置支付成功回调
monitor.onPaymentSuccess(async (payment) => {
  try {
    await splitBot.initialize();
    const result = await splitBot.buyPremium(payment.telegramId, payment.months);
    // 更新支付状态
    await updatePaymentStatus(payment.id, 'completed', result.transactionId);
    console.log(`成功为用户 ${payment.telegramId} 购买了 ${payment.months} 个月的Premium会员`);
  } catch (error) {
    console.error(`购买失败: ${error.message}`);
    // 更新支付状态为失败
    await updatePaymentStatus(payment.id, 'failed', null, error.message);
    // 通知管理员
    await notifyAdmin(`购买失败: ${error.message}`, payment);
  } finally {
    await splitBot.close();
  }
});

// 启动监听
monitor.start();
```

## 安全注意事项

- 钱包种子短语和密码应安全存储，建议使用环境变量或加密存储
- 定期更新脚本以适应Split平台的界面变化
- 设置交易金额限制，防止意外损失
- 实施IP轮换和请求限制，避免被平台封禁
- 定期备份钱包和交易记录

## 故障排除

### 常见问题

1. **登录失败**
   - 检查钱包凭证是否正确
   - 确认TON钱包扩展是否正常工作
   - 检查网络连接

2. **购买失败**
   - 检查钱包余额是否充足
   - 确认用户Telegram ID是否有效
   - 查看Split平台是否有维护或更新

3. **浏览器崩溃**
   - 增加内存限制
   - 更新Chrome和Puppeteer版本
   - 减少并发任务数量

## 维护与更新

- 定期检查Split平台界面变化
- 更新选择器和导航路径
- 优化性能和资源使用
- 增强错误处理和自动恢复能力

## 许可证

MIT
