# Split平台自动化脚本使用说明

## 概述

本自动化脚本用于在用户完成USDT转账后，自动在Split平台上为用户购买Telegram Premium会员。整个流程完全自动化，无需人工干预。

## 功能特点

- **全自动化流程**：从USDT转账监听到Split平台购买，全程自动化
- **智能错误处理**：内置错误检测、分析和自动重试机制
- **完善的日志记录**：详细记录每一步操作和可能的错误
- **安全的凭证管理**：通过环境变量安全存储敏感信息
- **灵活的配置选项**：可根据需求调整各项参数

## 系统要求

- Node.js 16.0.0 或更高版本
- Chrome 浏览器
- TON钱包浏览器扩展
- 稳定的网络连接

## 安装步骤

1. 克隆或解压代码到服务器
2. 运行安装脚本：
   ```bash
   chmod +x setup.sh
   ./setup.sh
   ```
3. 编辑`.env`文件，填入您的实际配置信息：
   - TON钱包路径和凭证
   - USDT监听配置
   - 其他自定义选项

4. 安装依赖：
   ```bash
   npm install
   ```

## 配置说明

### 必要配置

- `TON_WALLET_PATH`：TON钱包扩展的路径
- `WALLET_SEED`：钱包种子短语（请妥善保管！）
- `WALLET_PASSWORD`：钱包密码（请妥善保管！）
- `WALLET_ADDRESS`：USDT接收钱包地址
- `CONTRACT_ADDRESS`：USDT合约地址
- `TRONGRID_API_KEY`：TronGrid API密钥

### 可选配置

- `HEADLESS`：是否使用无头模式（true/false）
- `TIMEOUT`：操作超时时间（毫秒）
- `CHECK_INTERVAL`：USDT转账检查间隔（毫秒）
- `LOG_PATH`：日志存储路径

## 使用方法

### 启动服务

```bash
npm start
```

启动后，服务将自动监听USDT转账，并在检测到转账后自动在Split平台上购买Telegram Premium会员。

### 测试功能

```bash
# 运行所有测试（不包括实际购买）
npm test

# 包括实际购买的测试（将消耗TON）
RUN_PURCHASE_TEST=true npm test
```

## 日志和监控

- 所有日志默认保存在`logs`目录下
- 错误日志单独保存，便于排查问题
- 交易记录保存在`data/transactions.json`中

## 安全注意事项

1. **钱包凭证保护**：
   - 不要在代码中硬编码钱包种子短语和密码
   - 使用环境变量或加密存储
   - 限制配置文件的访问权限

2. **资金安全**：
   - 在钱包中只保留必要的TON金额
   - 定期检查交易记录
   - 设置交易金额上限

3. **服务器安全**：
   - 使用防火墙限制访问
   - 定期更新系统和依赖
   - 监控异常活动

## 故障排除

### 常见问题

1. **无法连接钱包**
   - 检查钱包扩展路径是否正确
   - 确认钱包凭证是否有效
   - 检查Chrome版本兼容性

2. **购买失败**
   - 检查钱包余额是否充足
   - 确认用户Telegram ID是否有效
   - 查看Split平台是否有维护或更新

3. **监听不到USDT转账**
   - 检查TronGrid API密钥是否有效
   - 确认钱包地址和合约地址是否正确
   - 检查网络连接是否稳定

### 日志分析

错误日志格式为：`[时间戳] [ERROR] 上下文: 错误信息`

例如：
```
[2025-05-26T07:30:45.123Z] [ERROR] 购买Premium会员 (尝试 1/4): 无法找到确认按钮
```

## 维护与更新

- 定期检查Split平台界面变化
- 更新选择器和导航路径
- 优化性能和资源使用
- 增强错误处理和自动恢复能力

## 支持与联系

如有任何问题或需要帮助，请联系管理员。
